#include "StdAfx.h"
#include ".\simpleimageshape.h"

#include "ScriptletConstant.h"
#include "Application.h"
#include "GDIPlusImage.h"

REGISTER_COMPONENT_CREATOR(SCRIPTLET_IMAGE_NODE, CSimpleImageShape);
IMPLEMENT_RTTI(CSimpleImageShape, CDrawingShape);
CSimpleImageShape::CSimpleImageShape(void)
{
	m_pImage = NULL;
}

CSimpleImageShape::~CSimpleImageShape(void)
{
	UnloadImage();
}
void CSimpleImageShape::SetImage(IImage* pImage)
{
	m_pImage = pImage;
}
void CSimpleImageShape::SetImage(LPCTSTR pszcID)
{
	m_IdImage = pszcID;
	LoadImage();
}
void CSimpleImageShape::LoadImage()
{
	if (m_pImage == NULL && _tcslen(m_IdImage) > 0)
	{
		IImage* image = Application::LoadImage(m_IdImage);
		if (image == NULL)
		{
			image = LoadImageFromURL(m_IdImage);
		}
		if (image != NULL)
		{
			SetImage(image);
		}
	}
}
IImage* CSimpleImageShape::LoadImageFromURL(LPCTSTR url)
{
	IImage* image = NULL;
	CNByteArray buffer;
	if (CNByteArray::ReadBufferFromURL(buffer, url))
	{
		CGDIPlusImage* gdiPimage = new CGDIPlusImage();
		if (FALSE == gdiPimage->Load(buffer.GetBuffer(), buffer.GetSize()))
		{
			delete gdiPimage;			
		}
		else
		{
			image = gdiPimage;
		}
	}
	return image;
}
void CSimpleImageShape::UnloadImage()
{
	if (m_pImage != NULL)
	{
		delete m_pImage;
		m_pImage = NULL;
	}
}
void CSimpleImageShape::OnParentVisibleChanged(CComponent* parent, BOOL bVisible)
{
	__super::OnParentVisibleChanged(parent, bVisible);
	/*
	if (bVisible)
	{
		LoadImage();
	}
	else
	{
		UnloadImage();
	}
	*/
}
void CSimpleImageShape::DrawComponent(HDC hDC)
{
	if (m_pImage)
	{
		CRect rcBound(0, 0, m_pImage->GetWidth(), m_pImage->GetHeight());
		CRect rcClient;
		GetDrawingBounds(&rcClient);
		m_pImage->DrawImage(hDC, &rcBound, &rcClient);
	}
}
BOOL CSimpleImageShape::GetOrginPreferredSize(LPSIZE lpSize)
{
	CSize sPreferred(0, 0);
	if (__super::GetOrginPreferredSize(&sPreferred))
	{
		if (sPreferred.cx == 0 && m_pImage != NULL)
		{
			sPreferred.cx = m_pImage->GetWidth();
		}
		if (sPreferred.cy == 0 && m_pImage != NULL)
		{
			sPreferred.cy = m_pImage->GetHeight();
		}
		if (sPreferred.cx > 0 && sPreferred.cy > 0)
		{
			lpSize->cx = sPreferred.cx;
			lpSize->cy = sPreferred.cy;
			return TRUE;
		}
	}
	if (m_pImage == NULL) return FALSE;
	lpSize->cx = m_pImage->GetWidth();
	lpSize->cy = m_pImage->GetHeight();
	return TRUE;
}